@@ -10,6 +10,8 @@
 #include <qstring.h>
 #include <qtimer.h>
 #include "tbuddylist.h"
+#include <klocale.h>
+#include <qregexp.h>
 
 /* For ScreenSaver stuff */
 
@@ -103,6 +105,9 @@ void TAim::setBuddyList(const TBuddyList &a){
   sendConfig();
   emit configChanged();
   timerLock = false;
+
+  // Lets keep track of these.
+  setServerBuddyList(a);
 }
 void TAim::setPermitList(const TBuddyList &a)
 {
@@ -128,6 +133,16 @@ void TAim::doIdleTime(bool doit)
 {
 	updateIdleTime = doit;
 }
+
+void TAim::setIdleTime(int time){
+  if( time >= 60*10 ){
+    isIdle = true;
+    QString data;
+    data.sprintf("toc_set_idle %i", time);
+    socket->writeData(data);
+  }
+}
+
 void TAim::useCustomServer(int use)
 {
 	usingCustomServer = use ? true : false;
@@ -151,6 +166,7 @@ void TAim::setSocksProxy(const QString &h, unsigned short p, bool a, const QStri
 	//socksName = name;
 	//socksPassword = pwd;
 }
+
 void TAim::setServerBuddyList(const TBuddyList &a)
 {
 	serverConfig.buddyList = a;
@@ -554,6 +570,13 @@ void TAim::tocServer(void)
 	end_case_tocServer
 	case_tocServer("CONFIG", 6)
 		tocParseConfig(data, &(serverConfig.buddyList), &(serverConfig.permitList), &(serverConfig.denyList), &(serverConfig.permitStatus));
+
+  TBuddyList slist = serverBuddyList();
+  TBuddyList list = buddyList();
+  list += slist;
+  setBuddyList(list);
+  emit reloadList();
+
 	end_case_tocServer
 	case_tocServer("NICK", 4)
 	  doNick(data);	
@@ -625,12 +648,12 @@ void TAim::endIdleness(void)
 void TAim::updateIdleness(void){
   timerLock = false; 
   if(!socket){
-		if (timerLock != true){	
-			timerLock = true;	  
-			QTimer::singleShot( 60000, this, SLOT(updateIdleness()) );
-		}
-		return;
-	}
+    if (timerLock != true){	
+      timerLock = true;	  
+      QTimer::singleShot( 60000, this, SLOT(updateIdleness()) );
+    }
+    return;
+  }
   
   // set idle after 10 minutes
   int difference = (int)difftime(time(0), idleTime);
@@ -659,62 +682,64 @@ void TAim::updateIdleness(void){
     socket->writeData(data);
   }
 	
-	if (idleTimeBeforeSignal == difference/60){
-	  emit (idleTimeReached());
-	}
-			
+  if (idleTimeBeforeSignal == difference/60){
+    emit (idleTimeReached());
+  }
+
   const int numberOfBuddies = currentConfig.buddyList.getCount();
-	for (int currentNum=0; currentNum < numberOfBuddies; currentNum++) {
-		TBuddy *tempBuddy = NULL; 
-		tempBuddy = currentConfig.buddyList.getByNum(currentNum);
-		if (tempBuddy != NULL){
-			if (tempBuddy->idleTime > 0){
-				tempBuddy->idleTime = (tempBuddy->idleTime)+1;
+  for (int currentNum=0; currentNum < numberOfBuddies; currentNum++) {
+    TBuddy *tempBuddy = NULL; 
+    tempBuddy = currentConfig.buddyList.getByNum(currentNum);
+    if (tempBuddy != NULL){
+      if (tempBuddy->idleTime > 0){
+        tempBuddy->idleTime = (tempBuddy->idleTime)+1;
        
-				// Update the idle time string 
-				int minute = tempBuddy->idleTime;
-    		int hour=0;
-    		while (minute > 59){
-      		hour++;
-      		minute = minute-60;
-    		}
+        // Update the idle time string 
+        int minute = tempBuddy->idleTime;
+    	int hour=0;
+    	while (minute > 59){
+      	  hour++;
+      	  minute = minute-60;
+    	}
 
-    		QString mid = "h ";
-    		QString post = "m";
-    		if (idleStringWColon == true){
-      		mid = ":";
-      		post = "";
-    		}
+    	QString mid = "h ";
+    	QString post = "m";
+    	if (idleStringWColon == true){
+      	  mid = ":";
+      	  post = "";
+        }
 
-    		if (minute < 10)
-      		mid += "0";
-    		tempBuddy->idleTimeString =  QString("%1%3%2%4").arg(hour).arg(minute).arg(mid).arg(post);
+    	if (minute < 10)
+      	  mid += "0";
+    	tempBuddy->idleTimeString =  QString("%1%3%2%4").arg(hour).arg(minute).arg(mid).arg(post);
     
-    		if (hour <= 0 && minute <= 0)
-      		tempBuddy->idleTimeString = "";
-				if (tempBuddy->status ==  TAIM_ONLINE)
-        	emit buddyChanged(currentNum);
-			}
-		}
+    	if (hour <= 0 && minute <= 0)
+      	  tempBuddy->idleTimeString = "";
+        if (tempBuddy->status ==  TAIM_ONLINE){
+          emit buddyChanged(currentNum);
+        }
+      }
+    }
   } 
-
 	
   // check again in a minute
   if (timerLock != true){	
-		timerLock = true;	  
-		QTimer::singleShot( 60000, this, SLOT(updateIdleness()) );
-	}
+    timerLock = true;	  
+    QTimer::singleShot( 60000, this, SLOT(updateIdleness()) );
+  }
 }
+
 // * TAim -- private *
 void TAim::tocSignon(const QString &auth_host, const QString &auth_port, const QString &lang)
 {
-	QString data;
-	//data.sprintf("toc_signon %s %s  %s %s %s %s", auth_host.latin1(), auth_port.latin1(),(tocNormalize(username)).latin1(), r_password.latin1(),TOC_LANG, tocProcess("TIK:$Revision: 1.46 $").latin1());
-	data.sprintf("toc_signon %s %s  %s %s %s %s", auth_host.latin1(), auth_port.latin1(),(tocNormalize(username)).latin1(), r_password.latin1(),TOC_LANG, tocProcess("kinkatta:\\$Revision: 1.46 $").latin1());
-	//data.sprintf("toc_signon %s %s  %s %s %s \"TIK:$Revision: 1.46 $\"", auth_host.latin1(), auth_port.latin1(), (tocNormalize(username)).latin1(), r_password.latin1(), lang.latin1());
+  QString data;
+  //data.sprintf("toc_signon %s %s  %s %s %s \"TIK:\\$Revision: 1.62 $\"", auth_host.latin1(), auth_port.latin1(), (tocNormalize(username)).latin1(), r_password.latin1(), TOC_LANG); 
+  
+  data.sprintf("toc_signon %s %s  %s %s %s \"penguin\"", auth_host.latin1(), auth_port.latin1(), (tocNormalize(username)).latin1(), r_password.latin1(), TOC_LANG); 
+  
 
   // frame is set up, now send it
-    socket->writeData(data);
+  socket->writeData(data);
 }
 void TAim::tocInitDone(void){
   QString data = "toc_init_done";
@@ -821,30 +846,34 @@ void TAim::sendUserInfo(void)
 }
 void TAim::doUpdate(const QString &data)
 {
-	TBuddy buddy;
-	QString workstr;
-	QString holding;
-	int i;
+  TBuddy buddy;
+  QString workstr;
+  QString holding;
+  int i;
 
-	workstr = data;
+  workstr = data;
 
-	// skip the "UPDATE_BUDDY:"
-	workstr.remove(0, 13);
+  // skip the "UPDATE_BUDDY:"
+  workstr.remove(0, 13);
 
-	// name
-	i = workstr.find(':');
-	buddy.name = workstr.left(i);
-	// skip past the colon
-	workstr.remove(0, i + 1);
+  // name
+  i = workstr.find(':');
+  buddy.name = workstr.left(i);
+  // skip past the colon
+  workstr.remove(0, i + 1);
 
-	// status:  T or F
-	buddy.status = (workstr[0] == 'T');
+  // status:  T or F
+  bool newStatus = (workstr[0] == 'T');
+  if( newStatus != TAIM_ONLINE && buddy.status == TAIM_ONLINE ){
+    emit (userSignedOff(buddy.name));
+  }
+  buddy.status = newStatus;
 	
-	// skip the status and the colon
-	workstr.remove(0, 2);
+  // skip the status and the colon
+  workstr.remove(0, 2);
 
-	// evil amount : 0 to 100
-	i = workstr.find(':');
+  // evil amount : 0 to 100
+  i = workstr.find(':');
 	holding = workstr.left(i);
 	buddy.evil = holding.toInt();
 	workstr.remove(0, i + 1);
@@ -863,16 +892,15 @@ void TAim::doUpdate(const QString &data)
 	// The signed off, get current time.
 	if (buddy.status == 0){
 		QDate theDate(1970,1,1);
-		//QTime theTime();
 		QDateTime dt(theDate);
 		int sec = dt.secsTo(QDateTime::currentDateTime());
 		buddy.lastOn = sec + (5*60*60);
 	}
 	workstr.remove(0, i + 1);
 
-	QTime theTime(0,0,0,0);
+  QTime theTime(0,0,0,0);
   QString lastOnString = "";
-	if (buddy.status != 0){
+  if (buddy.status != 0){
      lastOnString = "Now";
   }
   else  
@@ -962,8 +990,10 @@ void TAim::doUpdate(const QString &data)
     TBuddy *bud = new TBuddy;
     currentConfig.buddyList.get(bud, currentNum);
     
-    if ( currentConfig.buddyList.getStatus(currentNum) == 0 && buddy.status == 1)
+    if ( currentConfig.buddyList.getStatus(currentNum) == 0 && buddy.status == 1){
 	emit userSignedOn(buddy.name);
+	emit userSignedOn(buddy.name, buddy.alias);
+    }
     if (bud->idleTime > 0 && buddy.idleTime == 0 && buddy.status == 1)
       emit userNotIdle(buddy.name);	    
     if (bud->userClass == TOC_USER_AWAY && buddy.userClass != TOC_USER_AWAY && buddy.status == 1)
@@ -1024,7 +1054,7 @@ void TAim::doIM(const QString &data)
 	isAuto = ( (char)(QChar)workstr[0] == 'T' ) ? true : false;
 	workstr.remove(0, 2);
 	// the rest is the message
-	emit IMReceived(senderName, workstr, isAuto);
+	emit IMReceived(workstr, senderName, isAuto);
 }
 void TAim::doEviled(const QString &data)
 {
@@ -1209,39 +1239,38 @@ void TAim::doError(const QString &data)
 	switch(errorno)
 	{
 		// general errors
-		doError_errorCase(901, ("%1 is not currently available."));
-    
+		doError_errorCase(901, i18n("%1 is not currently available."));
+		doError_errorCase(902, i18n("Warning of %1 not currently available."));
+		doError_errorCase(903, i18n("A message has been dropped; you are exceeding the server speed limit."));
 		// admin errors
-		doError_errorCase(911, ("Error validating input."));
-    doError_errorCase(912, ("Invalid account"));
-    doError_errorCase(913, ("Error encountered while processing request"));
-    doError_errorCase(914, ("Service unavailable"));
+		doError_errorCase(911, i18n("Error validating input."));
+		doError_errorCase(912, i18n("Invalid account"));
+		doError_errorCase(913, i18n("Error encountered while processing request"));
+		doError_errorCase(914, i18n("Service unavailable"));
    
-		doError_errorCase(902, ("Warning of %1 not currently available."));
-		doError_errorCase(903, ("A message has been dropped.  You are\nexceeding the server speed limit."));
 		// chat errors
-		doError_errorCase(950, ("Chat in %1 is unavailable."));
+		doError_errorCase(950, i18n("Chat in %1 is unavailable."));
 		// Message and information errors
-		doError_errorCase(960, ("You are sending messages too fast to %1."));
-		doError_errorCase(961, ("You missed a message from %1 because\nthe message was too big."));
-		doError_errorCase(962, ("You missed a message from %1 because\nthe message was sent too fast."));
+		doError_errorCase(960, i18n("You are sending messages too fast to %1."));
+		doError_errorCase(961, i18n("You missed a message from %1 because\nthe message was too big."));
+		doError_errorCase(962, i18n("You missed a message from %1 because\nthe message was sent too fast."));
 		// Directory errors
-		doError_errorCase(970, ("Search failed."));
-		doError_errorCase(971, ("Search returned too many matches."));
-		doError_errorCase(972, ("Search needs more qualifiers."));
-		doError_errorCase(973, ("Directory service temporarily unavailable."));
-		doError_errorCase(974, ("Email lookup is restricted."));
-		doError_errorCase(975, ("Keyword ignored."));
-		doError_errorCase(976, ("No Keywords."));
-		doError_errorCase(977, ("Language not supported."));
-		doError_errorCase(978, ("Country not supported."));
-		doError_errorCase(979, ("Unknown directory failure: %1"));
+		doError_errorCase(970, i18n("Search failed."));
+		doError_errorCase(971, i18n("Search returned too many matches."));
+		doError_errorCase(972, i18n("Search needs more qualifiers."));
+		doError_errorCase(973, i18n("Directory service temporarily unavailable."));
+		doError_errorCase(974, i18n("Email lookup is restricted."));
+		doError_errorCase(975, i18n("Keyword ignored."));
+		doError_errorCase(976, i18n("No Keywords."));
+		doError_errorCase(977, i18n("Language not supported."));
+		doError_errorCase(978, i18n("Country not supported."));
+		doError_errorCase(979, i18n("Unknown directory failure: %1"));
 		// Authorization errors
-		doError_errorCase(980, ("Incorrect screen name or password.  Login failed."));
-		doError_errorCase(981, ("The service is temporarily unavailable."));
-		doError_errorCase(982, ("Your warning level is currently too high to sign on."));
-		doError_errorCase(983, ("You have been connecting and disconnecting too frequently.\nWait 10 minutes and try again.  If you continue to try,\nyou will need to wait even longer."));
-		doError_errorCase(989, ("Unknown signon failure: %1"));
+		doError_errorCase(980, i18n("Incorrect screen name or password.  Login failed."));
+		doError_errorCase(981, i18n("The service is temporarily unavailable."));
+		doError_errorCase(982, i18n("Your warning level is currently too high to sign on."));
+		doError_errorCase(983, i18n("You have been connecting and disconnecting too frequently.\nWait 10 minutes and try again.  If you continue to try,\nyou will need to wait even longer."));
+		doError_errorCase(989, i18n("Unknown signon failure: %1"));
 	}
 #undef doError_errorCase
 
