@@ -9,6 +9,7 @@
 
 #ifndef AWAYWINDOWOPTIONSIMP_H
 #define AWAYWINDOWOPTIONSIMP_H
+
 #include <qwidget.h>
 #include <qpushbutton.h>
 #include <qcombobox.h>
@@ -17,26 +18,33 @@
 #include <awayoptions.h>
 #include <setup.h>
 
-class AwayWindowOptionsImp : public awayOptions
-{ 
-    Q_OBJECT
+/**
+ * Allows the user to change their away options and add/remove away messages
+ * @author Benjamin Meyer
+ */
+class AwayWindowOptionsImp : public awayOptions { 
+
+Q_OBJECT
 
 public:
-	AwayWindowOptionsImp( QWidget* parent = 0, const char* name = 0);
-	~AwayWindowOptionsImp();
-	void getData();
-	void updateData();
+  AwayWindowOptionsImp( QWidget* parent = 0, const char* name = 0);
+  void getData();
+  void updateData();
 
 private slots:
-	void awayMessageSelected(int number);
-	void addAwayMessage();
-	void newAwayMessage();
-	void removeAwayMessage();
+  void awayMessageSelected(int number);
+  void addAwayMessage();
+  void newAwayMessage();
+  void removeAwayMessage();
+
 private:
-//	AwayMessages *listOfMes;
-	int CurrentSelected;
-	settings_t *i_aimSettings;
+  int CurrentSelected;
+  /// Pointer to the settings class
+  settings_t *i_aimSettings;
 	
 };
 
-#endif // AWAYWINDOWOPTIONSIMP_H
+#endif
+
+// awayoptionsimp.h
+
