@@ -10,7 +10,8 @@
 #define CHATOPTIONSIMP_H
 
 #include <chatoptions.h>
-#include <setup.h>
+class QFont;
+class QLabel;
 
 /**
   *@author Benjamin Meyer
@@ -20,21 +21,24 @@ class ChatOptionsImp : public ChatOptions  {
 
 Q_OBJECT
 	
-signals:
-  void saveSettings();
-  void chatToolbarUpdated();
-  void chatRoomToolbarUpdated();
-
 public:
   ChatOptionsImp(QWidget *parent=0, const char *name=0);
-  ~ChatOptionsImp();
 
 public slots:
   void updateData();
   void getData();
 
+private slots:
+  void changeUserFont();
+  void changeBuddyFont();
+  void setDefaultUserFont();
+  void setDefaultBuddyFont();
+
 private:
-  settings_t *i_aimSettings;
+  void updateFontSetting(QFont &f, QLabel *l);
+  void updateLabel( QLabel *l, const QFont &f );
+  QFont chat_yourFont;
+  QFont chat_contactFont;
 
 };
 
