@@ -30,10 +30,18 @@ public:
 public slots:
   void updateData();
   void getData();
+  void changebuddylistOnlineFont();
+  void changebuddylistOfflineFont();
+  void changebuddylistSignOnFont();
+  void setDefaultbuddylistOnlineFont();
+  void setDefaultbuddylistOfflineFont();
+  void setDefaultbuddylistSignOnFont();
 
 private slots:
 		
 private:
+  void updateFontSetting(QFont &f, QLabel *l);
+  void updateLabel(QLabel *l, const QFont &f);
   settings_t *i_aimSettings;
 
 };
@@ -41,3 +49,4 @@ private:
 #endif
 
 // MainWindowOptionsImp.h
+
