@@ -11,6 +11,8 @@
 
 #include <textoptions.h>
 #include <setup.h>
+class QFont;
+class QColor;
 
 /**
   *@author Benjamin Meyer
@@ -40,31 +42,24 @@ private slots:
   void changeUserBGColor();
   void setDefaultBuddyColors();
   void setDefaultUserColors();
-  void changeUserFont();
-  void changeBuddyFont();
-  void setDefaultUserFont();
-  void setDefaultBuddyFont();
-  void changebuddylistOnlineFont();
-  void changebuddylistOfflineFont();
-  void changebuddylistSignOnFont();
-  void setDefaultbuddylistOnlineFont();
-  void setDefaultbuddylistOfflineFont();
-  void setDefaultbuddylistSignOnFont();
 
 private:
-	void updateFontSetting(QFont &f, QLabel *l);
-	void updateLabel(QLabel *l, const QFont &f);
   settings_t *i_aimSettings;
   void getNewColor(QColor &c, QPushButton *l);
+
+  QFont chat_yourFont;
+  QFont chat_contactFont;
+
+  QColor chat_yourText_color;
+  QColor chat_yourName_color;
+  QColor chat_contactText_color;
+  QColor chat_contactName_color;
+  QColor chat_yourbg_color;
+  QColor chat_contactbg_color;
+
 };
 
 #endif
 
 // TextOptionsImp.h
 
-
-
-
-
-
-
