@@ -6,21 +6,22 @@
     email                : benjamin@csh.rit.edu
  ***************************************************************************/
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
-
 #include "setup.h"
-#include "aim.h"
+#include "network/aim.h"
+#include "application.h"
 #include <qprogressdialog.h>
 #include <qfont.h>
 #include <kprocess.h>
 #include <stdlib.h>
+#include "preferences.h"
+#include <kconfig.h>
+#include <kglobal.h>
+#include <qmultilineedit.h>
+#include <qdir.h>
+#include <qmessagebox.h>
+#include <qfile.h>
+#include <qtextstream.h>
+#include <qstring.h>
 
 //The default profile for new users, or users with no profile set yet.
 #define DEFAULT_PROFILE "<P>Visit the Kinkatta website at: <A HREF=\"http://kinkatta.sourceforge.net/\">http://kinkatta.sourceforge.net/</A>.</P>"
@@ -49,9 +50,9 @@ settings_t *setup::settings(void){
   return setup::instance()->i_currentSettings;
 }
 
-/***************************************************************************
+/**
  * Constructor
- ***************************************************************************/
+ **/
 setup::setup(){
   KDEHOMEDIR = getenv("KDEHOME");
   if (KDEHOMEDIR.length() == 0)
@@ -60,20 +61,10 @@ setup::setup(){
   i_currentSettings = new settings_t;
   
   // Set up basic defaults
-  i_currentSettings->Version = "Version 1.00";
-  i_currentSettings->ReleaseDate = "10/29/01";
+  i_currentSettings->Version = release_number;
+  i_currentSettings->ReleaseDate = release_date;
 
-  i_currentSettings->chatSettings = new chat_Settings;
-  i_currentSettings->chatColorSettings = new chat_Color_Settings;
-  i_currentSettings->chatFontSettings = new chat_Font_Settings;
   i_currentSettings->buddylistFontSettings = new buddylist_Font_Settings;
-  i_currentSettings->chatSoundSettings = new chat_Sound_Settings;
-  i_currentSettings->chatToolBarSettings = new chat_ToolBar_Settings;
-  i_currentSettings->imToolBarSettings = new im_ToolBar_Settings;
-
-  i_currentSettings->chatRoomToolBarSettings = new chat_ToolBar_Settings;
-  i_currentSettings->crToolBarSettings = new room_ToolBar_Settings;
-
   i_currentSettings->mapAwayMessages = new QMap<QString, QString>;
 }
 
@@ -81,16 +72,8 @@ setup::setup(){
  * Deconstructor
  ***************************************************************************/
 setup::~setup(){
-  delete i_currentSettings->chatSettings;
-  delete i_currentSettings->chatColorSettings;
   delete i_currentSettings->buddylistFontSettings;
-  delete i_currentSettings->chatFontSettings;
-  delete i_currentSettings->chatSoundSettings;
-  delete i_currentSettings->chatToolBarSettings;
-  delete i_currentSettings->imToolBarSettings;
   delete i_currentSettings->mapAwayMessages;
-  delete i_currentSettings->chatRoomToolBarSettings;
-  delete i_currentSettings->crToolBarSettings;
 
   delete i_currentSettings;
 }
@@ -142,7 +125,6 @@ bool setup::isRegisteredUser(QString &user){
  * Save the settings to the file
  ***************************************************************************/
 void setup::save(){
-  // Gets Window Placement
   // int winX = this->x();
   // int winY = this->y();
 	//qDebug("::save() i_currentSettings->login_name %s\n", i_currentSettings->login_name.latin1());
@@ -203,141 +185,31 @@ void setup::save(){
 	prefs.setBool("main_loginMoveLeft", i_currentSettings->main_loginMoveLeft);
 	prefs.setBool("main_loginMoveNo", i_currentSettings->main_loginMoveNo);
 	prefs.setBool("main_showIdle", i_currentSettings->main_showIdle);
-	prefs.setString("main_browser", i_currentSettings->main_browser);
 	prefs.setBool("main_showLastOn", i_currentSettings->main_showLastOn);
 	prefs.setBool("main_noIcons", i_currentSettings->main_noIcons);
 	prefs.setNumber("main_moveDown", i_currentSettings->main_moveDown);
 	prefs.setNumber("main_idleLayout", i_currentSettings->main_idleLayout);
 	prefs.setBool("main_noHeader", i_currentSettings->main_noHeader);
 	prefs.setBool("main_useX11ForIdle", i_currentSettings->main_useX11ForIdle);
+	prefs.setBool("main_showTraySignonTooltip", i_currentSettings->main_showTraySignonTooltip);
+	prefs.setNumber("main_traySignonTooltipPosX",
+		i_currentSettings->main_traySignonTooltipPosX);
+	prefs.setNumber("main_traySignonTooltipPosY",
+		i_currentSettings->main_traySignonTooltipPosY);
+	prefs.setNumber("main_traySignonTooltipAnchorPosition",
+		i_currentSettings->main_traySignonTooltipAnchorPosition);
 	prefs.setBool("main_mute_on_login", i_currentSettings->main_mute_on_login);
-	prefs.setBool("main_log_on_off", i_currentSettings->main_log_on_off);
 
 	prefs.setNumber("xSize", i_currentSettings->xSize);
 	prefs.setNumber("ySize", i_currentSettings->ySize);
 
-	prefs.setNumber("chatWindowXSize", i_currentSettings->chatWindowXSize );
-	prefs.setNumber("chatWindowYSize", i_currentSettings->chatWindowYSize );
-  prefs.setNumber("chatWindowSplitterHeight", i_currentSettings->chatWindowSplitterHeight );
-
-  prefs.setNumber("chatRoomXSize", i_currentSettings->chatRoomXSize );
-	prefs.setNumber("chatRoomYSize", i_currentSettings->chatRoomYSize );
-  prefs.setNumber("chatRoomSplitterHeight", i_currentSettings->chatRoomSplitterHeight );
-  prefs.setNumber("chatRoomSplitter2Width", i_currentSettings->chatRoomSplitter2Width );
-
 	prefs.setGroup("chat");
-	prefs.setBool("chat_raise_window", i_currentSettings->chatSettings->chat_raise_window);
-	prefs.setBool("chat_flash_on_new_message", i_currentSettings->chatSettings->chat_flash_on_new_message );
-	prefs.setBool("chat_log", i_currentSettings->chatSettings->chat_log );
-	prefs.setBool("chat_log_inHtml", i_currentSettings->chatSettings->chat_log_inHtml);
-	prefs.setBool("chat_show_time", i_currentSettings->chatSettings->chat_show_time );
-	prefs.setBool("chat_log_time", i_currentSettings->chatSettings->chat_log_time);
-	prefs.setBool("chat_return_send", i_currentSettings->chatSettings->chat_return_send);
-	prefs.setBool("chat_sreturn_send", i_currentSettings->chatSettings->chat_sreturn_send);
-	prefs.setBool("chat_send_blank", i_currentSettings->chatSettings->chat_send_blank);
-	prefs.setBool("chat_ignore_buddyhtml", i_currentSettings->chatSettings->chat_ignore_buddyhtml);
-	prefs.setBool("chat_show_smilies", i_currentSettings->chatSettings->chat_show_smilies);
-	prefs.setBool("chat_line_limit", i_currentSettings->chatSettings->chat_line_limit);
-	prefs.setNumber("chat_line_limit_number", i_currentSettings->chatSettings->chat_line_limit_number);
-	prefs.setBool("chat_log_singleFile", i_currentSettings->chatSettings->chat_log_singleFile);
-	prefs.setBool("chat_crypt", i_currentSettings->chatSettings->chat_crypt);
-
-	// Chat Room Toolbar
-	prefs.setBool("room_view_text", i_currentSettings->chatRoomToolBarSettings->view_text);
-	prefs.setBool("room_view_chat", i_currentSettings->chatRoomToolBarSettings->view_chat);
-	prefs.setNumber("room_loc_text", i_currentSettings->chatRoomToolBarSettings->loc_text);
-	prefs.setNumber("room_loc_chat" , i_currentSettings->chatRoomToolBarSettings->loc_chat);
-	prefs.setBool("room_text_bold", (i_currentSettings->chatRoomToolBarSettings->text_bold));
-	prefs.setBool("room_text_italic", (i_currentSettings->chatRoomToolBarSettings->text_italic) );
-	prefs.setBool("room_text_underline", (i_currentSettings->chatRoomToolBarSettings->text_underline) );
-	prefs.setBool("room_text_fontdown", (i_currentSettings->chatRoomToolBarSettings->text_fontdown) );
-	prefs.setBool("room_text_fontnormal", (i_currentSettings->chatRoomToolBarSettings->text_fontnormal) ) ;
-	prefs.setBool("room_text_fontbig", (i_currentSettings->chatRoomToolBarSettings->text_fontbig) );
-	prefs.setBool("room_text_bgcolor", (i_currentSettings->chatRoomToolBarSettings->text_bgcolor) );
-	prefs.setBool("room_text_pencolor", (i_currentSettings->chatRoomToolBarSettings->text_pencolor) );
-	prefs.setBool("room_text_link", (i_currentSettings->chatRoomToolBarSettings->text_link) );
-	prefs.setBool("room_text_smiley", (i_currentSettings->chatRoomToolBarSettings->text_smiley) );
-	prefs.setBool("room_chat_clear", (i_currentSettings->chatRoomToolBarSettings->chat_clear) );
-	prefs.setBool("room_chat_save", (i_currentSettings->chatRoomToolBarSettings->chat_save) );
-	prefs.setBool("room_chat_print", (i_currentSettings->chatRoomToolBarSettings->chat_print) );
-	prefs.setBool("room_chat_time", (i_currentSettings->chatRoomToolBarSettings->chat_time) );
-	prefs.setBool("room_chat_log", (i_currentSettings->chatRoomToolBarSettings->chat_log) );
-	prefs.setBool("room_chat_sound", (i_currentSettings->chatRoomToolBarSettings->chat_sound) );
-	prefs.setBool("room_chat_invite", (i_currentSettings->crToolBarSettings->room_invite) );
-	prefs.setBool("room_chat_send", (i_currentSettings->chatRoomToolBarSettings->chat_send) );
-
-  // Chat Toolbar
-  prefs.setBool("singleChat_view_text", i_currentSettings->chatToolBarSettings->view_text);
-	prefs.setBool("singleChat_view_chat", i_currentSettings->chatToolBarSettings->view_chat);
-	prefs.setNumber("singleChat_loc_text", i_currentSettings->chatToolBarSettings->loc_text);
-	prefs.setNumber("singleChat_loc_chat" , i_currentSettings->chatToolBarSettings->loc_chat);
-	prefs.setBool("singleChat_text_bold", (i_currentSettings->chatToolBarSettings->text_bold));
-	prefs.setBool("singleChat_text_italic", (i_currentSettings->chatToolBarSettings->text_italic) );
-	prefs.setBool("singleChat_text_underline", (i_currentSettings->chatToolBarSettings->text_underline) );
-	prefs.setBool("singleChat_text_fontdown", (i_currentSettings->chatToolBarSettings->text_fontdown) );
-	prefs.setBool("singleChat_text_fontnormal", (i_currentSettings->chatToolBarSettings->text_fontnormal) ) ;
-	prefs.setBool("singleChat_text_fontbig", (i_currentSettings->chatToolBarSettings->text_fontbig) );
-	prefs.setBool("singleChat_text_bgcolor", (i_currentSettings->chatToolBarSettings->text_bgcolor) );
-	prefs.setBool("singleChat_text_pencolor", (i_currentSettings->chatToolBarSettings->text_pencolor) );
-	prefs.setBool("singleChat_text_link", (i_currentSettings->chatToolBarSettings->text_link) );
-	prefs.setBool("singleChat_text_smiley", (i_currentSettings->chatToolBarSettings->text_smiley) );
-	prefs.setBool("singleChat_chat_clear", (i_currentSettings->chatToolBarSettings->chat_clear) );
-	prefs.setBool("singleChat_chat_save", (i_currentSettings->chatToolBarSettings->chat_save) );
-	prefs.setBool("singleChat_chat_print", (i_currentSettings->chatToolBarSettings->chat_print) );
-	prefs.setBool("singleChat_chat_time", (i_currentSettings->chatToolBarSettings->chat_time) );
-	prefs.setBool("singleChat_chat_log", (i_currentSettings->chatToolBarSettings->chat_log) );
-	prefs.setBool("singleChat_chat_sound", (i_currentSettings->chatToolBarSettings->chat_sound) );
-
-  prefs.setBool("chat_remove", (i_currentSettings->imToolBarSettings->chat_remove) );
-	prefs.setBool("chat_warn", (i_currentSettings->imToolBarSettings->chat_warn) );
-	prefs.setBool("chat_block", (i_currentSettings->imToolBarSettings->chat_block) );
-	prefs.setBool("chat_info", (i_currentSettings->imToolBarSettings->chat_info) );
-	prefs.setBool("chat_pounce", (i_currentSettings->imToolBarSettings->chat_pounce) );
-	prefs.setBool("singleChat_chat_send", (i_currentSettings->chatToolBarSettings->chat_send) );
-
-
-  prefs.setNumber("chat_yourText_color.R" , i_currentSettings->chatColorSettings->chat_yourText_color.red());
-  prefs.setNumber("chat_yourText_color.G" , i_currentSettings->chatColorSettings->chat_yourText_color.green());
-  prefs.setNumber("chat_yourText_color.B" , i_currentSettings->chatColorSettings->chat_yourText_color.blue());
-  prefs.setNumber("chat_yourName_color.R", i_currentSettings->chatColorSettings->chat_yourName_color.red());
-  prefs.setNumber("chat_yourName_color.G", i_currentSettings->chatColorSettings->chat_yourName_color.green());
-  prefs.setNumber("chat_yourName_color.B", i_currentSettings->chatColorSettings->chat_yourName_color.blue());
-
-  prefs.setNumber("chat_buddyText_color.R", i_currentSettings->chatColorSettings->chat_buddyText_color.red());
-  prefs.setNumber("chat_buddyText_color.G", i_currentSettings->chatColorSettings->chat_buddyText_color.green());
-  prefs.setNumber("chat_buddyText_color.B", i_currentSettings->chatColorSettings->chat_buddyText_color.blue());
-
-  prefs.setNumber("chat_buddyName_color.R", i_currentSettings->chatColorSettings->chat_buddyName_color.red());
-  prefs.setNumber("chat_buddyName_color.G", i_currentSettings->chatColorSettings->chat_buddyName_color.green());
-  prefs.setNumber("chat_buddyName_color.B", i_currentSettings->chatColorSettings->chat_buddyName_color.blue());
-
-  prefs.setNumber("chat_buddyBg_color.R", i_currentSettings->chatColorSettings->chat_buddybg_color.red());
-  prefs.setNumber("chat_buddyBg_color.G", i_currentSettings->chatColorSettings->chat_buddybg_color.green());
-  prefs.setNumber("chat_buddyBg_color.B", i_currentSettings->chatColorSettings->chat_buddybg_color.blue());
-
-  prefs.setNumber("chat_yourBg_color.R", i_currentSettings->chatColorSettings->chat_yourbg_color.red());
-  prefs.setNumber("chat_yourBg_color.G", i_currentSettings->chatColorSettings->chat_yourbg_color.green());
-  prefs.setNumber("chat_yourBg_color.B", i_currentSettings->chatColorSettings->chat_yourbg_color.blue());
-
-	prefs.setFont("chat_yourFont", i_currentSettings->chatFontSettings->chat_yourFont);
-
-	prefs.setFont("chat_buddyFont", i_currentSettings->chatFontSettings->chat_buddyFont);
-
-	prefs.setFont("buddylist_OnlineFont", i_currentSettings->buddylistFontSettings->buddylist_OnlineFont);
 
+  	prefs.setFont("buddylist_OnlineFont", i_currentSettings->buddylistFontSettings->buddylist_OnlineFont);
 	prefs.setFont("buddylist_OfflineFont", i_currentSettings->buddylistFontSettings->buddylist_OfflineFont);
-
 	prefs.setFont("buddylist_SignOnFont", i_currentSettings->buddylistFontSettings->buddylist_SignOnFont);
 
-	prefs.setBool("chat_sound_enable", i_currentSettings->chatSoundSettings->chat_sound);
-	prefs.setBool("chat_sound_beepInitial", i_currentSettings->chatSoundSettings->chat_sound_beepInitial);
-	prefs.setBool("chat_sound_beepReceive", i_currentSettings->chatSoundSettings->chat_sound_beepReceive);
-	prefs.setBool("chat_sound_beepSend", i_currentSettings->chatSoundSettings->chat_sound_beepSend);
-	prefs.setBool("chat_sound_playFile", i_currentSettings->chatSoundSettings->chat_sound_playFile );
-	prefs.setString("chat_sound_fileSend" ,i_currentSettings->chatSoundSettings->chat_sound_fileSend);
-	prefs.setString("chat_sound_fileReceive" ,i_currentSettings->chatSoundSettings->chat_sound_fileReceive);
-	prefs.setString("chat_sound_fileInitial" , i_currentSettings->chatSoundSettings->chat_sound_fileInitial);
-	prefs.setString("IgnoreThisUpdate", i_currentSettings->IgnoreThisUpdate);
+  prefs.setString("IgnoreThisUpdate", i_currentSettings->IgnoreThisUpdate);
 
 	prefs.setGroup("away list");
 	QMap <QString,QString>::Iterator it;
@@ -557,6 +429,9 @@ void setup::parseBuddyListFile(const QString &settingsFileXml, TBuddyList *buddy
 				  buddy.alias = "Jim Wilson";
 				}
 			}
+        if( buddy.name.lower() == QString("Dr HP Baldy") )
+          if( buddy.name == buddy.alias)
+            buddy.alias = "Adam Keys";
 
 			QString type = prefs.getAttr2( QString("buddy_%1").arg(i));
 			if( type == "permit" ){
@@ -608,6 +483,9 @@ void setup::resetDefaults(){
  * Read the settings from the file
  ***************************************************************************/
 void setup::read(){
+  KConfig &config = *KGlobal::config();
+  config.setGroup("chatwindow");
+
   int i, r, g, b;
   bool convertoldfiles = false;
   //Get File Name
@@ -688,154 +566,203 @@ void setup::read(){
 	i_currentSettings->main_loginMoveLeft= prefs.getBool("main_loginMoveLeft", false);
 	i_currentSettings->main_loginMoveNo	= prefs.getBool("main_loginMoveNo", true);
 	i_currentSettings->main_showIdle= prefs.getBool("main_showIdle", true);
-	i_currentSettings->main_browser = prefs.getString("main_browser", "netscape");
 	i_currentSettings->main_showLastOn= prefs.getBool("main_showLastOn", false);
 	i_currentSettings->main_noIcons= prefs.getBool("main_noIcons", false);
 	i_currentSettings->main_moveDown= prefs.getNumber("main_moveDown", 0);
 	i_currentSettings->main_idleLayout= prefs.getNumber("main_idleLayout", 0);
 	i_currentSettings->main_noHeader= prefs.getBool("main_noHeader", false);
 	i_currentSettings->main_useX11ForIdle= prefs.getBool("main_useX11ForIdle", false );
+	i_currentSettings->main_showTraySignonTooltip= 
+				prefs.getBool("main_showTraySignonTooltip", true );
+	i_currentSettings->main_traySignonTooltipPosX= 
+				prefs.getNumber("main_traySignonTooltipPosX", 0 );
+	i_currentSettings->main_traySignonTooltipPosY= 
+				prefs.getNumber("main_traySignonTooltipPosY", 0 );
+	i_currentSettings->main_traySignonTooltipAnchorPosition= 
+				prefs.getNumber("main_traySignonTooltipAnchorPosition", 0 );
 	i_currentSettings->main_mute_on_login= prefs.getBool("main_mute_on_login", true );
-	i_currentSettings->main_log_on_off= prefs.getBool("main_log_on_off", false );
 
 	i_currentSettings->xSize= prefs.getNumber("xSize", -1);
 	i_currentSettings->ySize= prefs.getNumber("ySize", -1);
 
-	i_currentSettings->chatWindowXSize= prefs.getNumber("chatWindowXSize", 335);
-        if (i_currentSettings->chatWindowXSize == 330) {
-		/* convert old default to 335 so large toolbar buttons fit */
-		i_currentSettings->chatWindowXSize = 335;
-	}
-	i_currentSettings->chatWindowYSize= prefs.getNumber("chatWindowYSize", 330);
-	i_currentSettings->chatWindowSplitterHeight= prefs.getNumber("chatWindowSplitterHeight", 40);
-
-	i_currentSettings->chatRoomXSize= prefs.getNumber("chatRoomXSize", 447);
-	i_currentSettings->chatRoomYSize= prefs.getNumber("chatRoomYSize", 330);
-	i_currentSettings->chatRoomSplitterHeight= prefs.getNumber("chatRoomSplitterHeight", 40);
-	i_currentSettings->chatRoomSplitter2Width= prefs.getNumber("chatRoomSplitter2Width", 40);
-
 	prefs.setGroup("chat");
-	i_currentSettings->chatSettings->chat_raise_window= prefs.getBool("chat_raise_window", true);
-	i_currentSettings->chatSettings->chat_flash_on_new_message = prefs.getBool("chat_flash_on_new_message", true);
-	i_currentSettings->chatSettings->chat_log = prefs.getBool("chat_log", true);
-	i_currentSettings->chatSettings->chat_log_inHtml= prefs.getBool("chat_log_inHtml", true);
-	i_currentSettings->chatSettings->chat_show_time = prefs.getBool("chat_show_time", true);
-	i_currentSettings->chatSettings->chat_log_time= prefs.getBool("chat_log_time", true);
-	i_currentSettings->chatSettings->chat_return_send= prefs.getBool("chat_return_send", true);
-	i_currentSettings->chatSettings->chat_sreturn_send= prefs.getBool("chat_sreturn_send", false);
-	i_currentSettings->chatSettings->chat_send_blank= prefs.getBool("chat_send_blank", false);
-	i_currentSettings->chatSettings->chat_ignore_buddyhtml= prefs.getBool("chat_ignore_buddyhtml", false);
-	i_currentSettings->chatSettings->chat_show_smilies= prefs.getBool("chat_show_smilies", true);
-	i_currentSettings->chatSettings->chat_line_limit= prefs.getBool("chat_line_limit", false);
-	i_currentSettings->chatSettings->chat_line_limit_number= prefs.getNumber("chat_line_limit_number",200 );
-	i_currentSettings->chatSettings->chat_log_singleFile= prefs.getBool("chat_log_singleFile", false);
-	i_currentSettings->chatSettings->chat_crypt= prefs.getBool("chat_crypt", false);
+  bool chat_raise_window;         // Done
+  bool chat_flash_on_new_message; // Done
+  bool chat_log;                  // Done
+  bool chat_log_inHtml;           // Done
+  bool chat_show_time;            // Done
+  bool chat_log_time;             // Done
+  bool chat_return_send;	  			// Done
+  bool chat_sreturn_send;         // Done
+  bool chat_send_blank;           // Done
+  bool chat_ignore_contacthtml;   // Done
+  bool chat_line_limit;           // Done
+  bool chat_show_smilies;         // Done
+  int chat_line_limit_number;     // Done
+  bool chat_log_singleFile;
 
-	i_currentSettings->chatToolBarSettings->view_text= prefs.getBool("singleChat_view_text", true);
-	i_currentSettings->chatToolBarSettings->view_chat= prefs.getBool("singleChat_view_chat", true);
-	i_currentSettings->chatToolBarSettings->loc_text= prefs.getNumber("singleChat_loc_text", 0);
-	i_currentSettings->chatToolBarSettings->loc_chat= prefs.getNumber("singleChat_loc_chat", 0);
-	i_currentSettings->chatToolBarSettings->text_bold= prefs.getBool("singleChat_text_bold", true);
-	i_currentSettings->chatToolBarSettings->text_italic = prefs.getBool("singleChat_text_italic", true);
-	i_currentSettings->chatToolBarSettings->text_underline = prefs.getBool("singleChat_text_underline", true);
-	i_currentSettings->chatToolBarSettings->text_fontdown = prefs.getBool("singleChat_text_fontdown", true);
-	i_currentSettings->chatToolBarSettings->text_fontnormal= prefs.getBool("singleChat_text_fontnormal", true) ;
-	i_currentSettings->chatToolBarSettings->text_fontbig= prefs.getBool("singleChat_text_fontbig", true);
-	i_currentSettings->chatToolBarSettings->text_bgcolor= prefs.getBool("singleChat_text_bgcolor", true);
-	i_currentSettings->chatToolBarSettings->text_pencolor= prefs.getBool("singleChat_text_pencolor", true);
-	i_currentSettings->chatToolBarSettings->text_link= prefs.getBool("singleChat_text_link", true);
-	i_currentSettings->chatToolBarSettings->text_smiley= prefs.getBool("singleChat_text_smiley", true);
-	i_currentSettings->chatToolBarSettings->chat_clear= prefs.getBool("singleChat_chat_clear", true);
-	i_currentSettings->chatToolBarSettings->chat_save= prefs.getBool("singleChat_chat_save", true);
-	i_currentSettings->chatToolBarSettings->chat_print= prefs.getBool("singleChat_chat_print", false);
-	i_currentSettings->chatToolBarSettings->chat_time= prefs.getBool("singleChat_chat_time", true);
-	i_currentSettings->chatToolBarSettings->chat_log= prefs.getBool("singleChat_chat_log", true);
-	i_currentSettings->chatToolBarSettings->chat_sound= prefs.getBool("singleChat_chat_sound", true);
+chat_raise_window= config.readBoolEntry("chat_raise_window", true);
+chat_flash_on_new_message = config.readBoolEntry("chat_flash_on_new_message", true);
+chat_log = config.readBoolEntry("chat_log", true);
+chat_log_inHtml= config.readBoolEntry("chat_log_inHtml", true);
+chat_show_time = config.readBoolEntry("chat_show_time", true);
+chat_log_time= config.readBoolEntry("chat_log_time", true);
+chat_return_send= config.readBoolEntry("chat_return_send", true);
+chat_sreturn_send= config.readBoolEntry("chat_sreturn_send", false);
+chat_send_blank= config.readBoolEntry("chat_send_blank", false);
+chat_ignore_contacthtml= config.readBoolEntry("chat_ignore_buddyhtml", false);
+chat_show_smilies= config.readBoolEntry("chat_show_smilies", true);
+chat_line_limit= config.readBoolEntry("chat_line_limit", false);
+chat_line_limit_number= config.readNumEntry("chat_line_limit_number",200 );
+chat_log_singleFile= config.readBoolEntry("chat_log_singleFile", false);
 
-        i_currentSettings->imToolBarSettings->chat_remove= prefs.getBool("chat_remove", true);
-	i_currentSettings->imToolBarSettings->chat_warn= prefs.getBool("chat_warn", false);
-	i_currentSettings->imToolBarSettings->chat_block= prefs.getBool("chat_block", true);
-	i_currentSettings->imToolBarSettings->chat_pounce= prefs.getBool("chat_pounce", false);
-	i_currentSettings->imToolBarSettings->chat_info= prefs.getBool("chat_info", true);
-	i_currentSettings->chatToolBarSettings->chat_send= prefs.getBool("singleChat_chat_send", true);
+chat_raise_window= prefs.getBool("chat_raise_window", chat_raise_window);
+chat_flash_on_new_message = prefs.getBool("chat_flash_on_new_message", chat_flash_on_new_message);
+chat_log = prefs.getBool("chat_log", chat_log);
+chat_log_inHtml= prefs.getBool("chat_log_inHtml", chat_log_inHtml);
+chat_show_time = prefs.getBool("chat_show_time", chat_show_time);
+chat_log_time= prefs.getBool("chat_log_time", chat_log_time);
+chat_return_send= prefs.getBool("chat_return_send", chat_return_send);
+chat_sreturn_send= prefs.getBool("chat_sreturn_send", chat_sreturn_send);
+chat_send_blank= prefs.getBool("chat_send_blank", chat_send_blank);
+chat_ignore_contacthtml= prefs.getBool("chat_ignore_buddyhtml", chat_ignore_contacthtml);
+chat_show_smilies= prefs.getBool("chat_show_smilies", chat_show_smilies);
+chat_line_limit= prefs.getBool("chat_line_limit", chat_line_limit);
+chat_line_limit_number= prefs.getNumber("chat_line_limit_number",chat_line_limit_number );
+chat_log_singleFile= prefs.getBool("chat_log_singleFile", chat_log_singleFile);
 
-	// ChatRoom Toolbar
-	i_currentSettings->chatRoomToolBarSettings->view_text= prefs.getBool("room_view_text", true);
-	i_currentSettings->chatRoomToolBarSettings->view_chat= prefs.getBool("room_view_chat", true);
-	i_currentSettings->chatRoomToolBarSettings->loc_text= prefs.getNumber("room_loc_text", 0);
-	i_currentSettings->chatRoomToolBarSettings->loc_chat= prefs.getNumber("room_loc_chat", 0);
+  config.writeEntry("chat_raise_window", chat_raise_window);
+  config.writeEntry("chat_flash_on_new_message", chat_flash_on_new_message);
+  config.writeEntry("chat_log", chat_log);
+  config.writeEntry("chat_log_inHtml",chat_log_inHtml );
+  config.writeEntry("chat_log_singleFile", chat_log_singleFile);
+  config.writeEntry("chat_show_time", chat_show_time);
+  config.writeEntry("chat_log_time", chat_log_time);
+  config.writeEntry("chat_return_send", chat_return_send);
+  config.writeEntry("chat_sreturn_send", chat_sreturn_send);
+  config.writeEntry("chat_send_blank", chat_send_blank);
+  config.writeEntry("chat_ignore_contacthtml", chat_ignore_contacthtml);
+  config.writeEntry("chat_show_smilies", chat_show_smilies);
+  config.writeEntry("chat_line_limit", chat_line_limit);
+  config.writeEntry("chat_line_limit_number", chat_line_limit_number);
+  config.writeEntry("chat_log", chat_log);
 
-	i_currentSettings->chatRoomToolBarSettings->text_bold= prefs.getBool("room_text_bold", true);
-	i_currentSettings->chatRoomToolBarSettings->text_italic = prefs.getBool("room_text_italic", true);
-	i_currentSettings->chatRoomToolBarSettings->text_underline = prefs.getBool("room_text_underline", true);
-	i_currentSettings->chatRoomToolBarSettings->text_fontdown = prefs.getBool("room_text_fontdown", true);
-	i_currentSettings->chatRoomToolBarSettings->text_fontnormal= prefs.getBool("room_text_fontnormal", true) ;
-	i_currentSettings->chatRoomToolBarSettings->text_fontbig= prefs.getBool("room_text_fontbig", true);
-	i_currentSettings->chatRoomToolBarSettings->text_bgcolor= prefs.getBool("room_text_bgcolor", true);
-	i_currentSettings->chatRoomToolBarSettings->text_pencolor= prefs.getBool("room_text_pencolor", true);
-	i_currentSettings->chatRoomToolBarSettings->text_link= prefs.getBool("room_text_link", true);
-	i_currentSettings->chatRoomToolBarSettings->text_smiley= prefs.getBool("room_text_smiley", true);
-	i_currentSettings->chatRoomToolBarSettings->chat_clear= prefs.getBool("room_chat_clear", true);
-	i_currentSettings->chatRoomToolBarSettings->chat_save= prefs.getBool("room_chat_save", true);
-	i_currentSettings->chatRoomToolBarSettings->chat_print= prefs.getBool("room_chat_print", false);
-	i_currentSettings->chatRoomToolBarSettings->chat_time= prefs.getBool("room_chat_time", true);
-	i_currentSettings->chatRoomToolBarSettings->chat_log= prefs.getBool("room_chat_log", true);
-	i_currentSettings->chatRoomToolBarSettings->chat_sound= prefs.getBool("room_chat_sound", true);
-	i_currentSettings->crToolBarSettings->room_invite= prefs.getBool("room_chat_invite", true);
-	i_currentSettings->chatRoomToolBarSettings->chat_send= prefs.getBool("room_chat_send", true);
+  QColor chat_yourText_color;     // Done
+  QColor chat_yourName_color;     // Done
+  QColor chat_contactText_color;  // Done
+  QColor chat_contactName_color;  // Done
+  QColor chat_yourbg_color;       // Done
+  QColor chat_contactbg_color;    // Done
 
+  r = config.readNumEntry("chat_yourText_color.R", 0);
+  g = config.readNumEntry("chat_yourText_color.G", 0);
+  b = config.readNumEntry("chat_yourText_color.B", 0);
+  r = prefs.getNumber("chat_yourText_color.R", r);
+  g = prefs.getNumber("chat_yourText_color.G", g);
+  b = prefs.getNumber("chat_yourText_color.B", b);
+  chat_yourText_color.setRgb(r, g, b);
 
-	r = prefs.getNumber("chat_yourText_color.R", 0);
-  g = prefs.getNumber("chat_yourText_color.G", 0);
-  b = prefs.getNumber("chat_yourText_color.B", 0);
-	i_currentSettings->chatColorSettings->chat_yourText_color.setRgb(r, g, b);
+  r = config.readNumEntry("chat_yourName_color.R", 0);
+  g = config.readNumEntry("chat_yourName_color.G", 60);
+  b = config.readNumEntry("chat_yourName_color.B", 128);
+  r = prefs.getNumber("chat_yourName_color.R", r);
+  g = prefs.getNumber("chat_yourName_color.G", g);
+  b = prefs.getNumber("chat_yourName_color.B", b);
+  chat_yourName_color.setRgb(r, g, b);
 
-  r = prefs.getNumber("chat_yourName_color.R", 0);
-  g = prefs.getNumber("chat_yourName_color.G", 60);
-  b = prefs.getNumber("chat_yourName_color.B", 128);
-	i_currentSettings->chatColorSettings->chat_yourName_color.setRgb(r, g, b);
+  r = config.readNumEntry("chat_buddyText_color.R", 0);
+  g = config.readNumEntry("chat_buddyText_color.G", 0);
+  b = config.readNumEntry("chat_buddyText_color.B", 0);
+  r = prefs.getNumber("chat_buddyText_color.R", r);
+  g = prefs.getNumber("chat_buddyText_color.G", g);
+  b = prefs.getNumber("chat_buddyText_color.B", b);
+  chat_contactText_color.setRgb(r, g, b);
 
-  r = prefs.getNumber("chat_buddyText_color.R", 0);
-  g = prefs.getNumber("chat_buddyText_color.G", 0);
-  b = prefs.getNumber("chat_buddyText_color.B", 0);
-	i_currentSettings->chatColorSettings->chat_buddyText_color.setRgb(r, g, b);
+  r = config.readNumEntry("chat_buddyName_color.R", 128);
+  g = config.readNumEntry("chat_buddyName_color.G", 0);
+  b = config.readNumEntry("chat_buddyName_color.B", 0);
+  r = prefs.getNumber("chat_buddyName_color.R", r);
+  g = prefs.getNumber("chat_buddyName_color.G", g);
+  b = prefs.getNumber("chat_buddyName_color.B", b);
+  chat_contactName_color.setRgb(r, g, b);
 
-  r = prefs.getNumber("chat_buddyName_color.R", 128);
-  g = prefs.getNumber("chat_buddyName_color.G", 0);
-  b = prefs.getNumber("chat_buddyName_color.B", 0);
-	i_currentSettings->chatColorSettings->chat_buddyName_color.setRgb(r, g, b);
+  r = config.readNumEntry("chat_buddyBg_color.R", 255);
+  g = config.readNumEntry("chat_buddyBg_color.G", 255);
+  b = config.readNumEntry("chat_buddyBg_color.B", 255);
+  r = prefs.getNumber("chat_buddyBg_color.R", r);
+  g = prefs.getNumber("chat_buddyBg_color.G", g);
+  b = prefs.getNumber("chat_buddyBg_color.B", b);
+  chat_contactbg_color.setRgb(r, g, b);
 
-  r = prefs.getNumber("chat_buddyBg_color.R", 255);
-  g = prefs.getNumber("chat_buddyBg_color.G", 255);
-  b = prefs.getNumber("chat_buddyBg_color.B", 255);
-	i_currentSettings->chatColorSettings->chat_buddybg_color.setRgb(r, g, b);
+  r = config.readNumEntry("chat_yourBg_color.R", 255);
+  g = config.readNumEntry("chat_yourBg_color.G", 255);
+  b = config.readNumEntry("chat_yourBg_color.B", 255);
+  r = prefs.getNumber("chat_yourBg_color.R", r);
+  g = prefs.getNumber("chat_yourBg_color.G", g);
+  b = prefs.getNumber("chat_yourBg_color.B", b);
+  chat_yourbg_color.setRgb(r, g, b);
 
-  r = prefs.getNumber("chat_yourBg_color.R", 255);
-  g = prefs.getNumber("chat_yourBg_color.G", 255);
-  b = prefs.getNumber("chat_yourBg_color.B", 255);
-	i_currentSettings->chatColorSettings->chat_yourbg_color.setRgb(r, g, b);
+  config.writeEntry( "chat_yourText_color", chat_yourText_color );
+  config.writeEntry( "chat_yourName_color", chat_yourName_color );
+  config.writeEntry( "chat_contactText_color", chat_contactText_color );
+  config.writeEntry( "chat_contactName_color", chat_contactName_color );
+  config.writeEntry( "chat_yourbg_color", chat_yourbg_color );
+  config.writeEntry( "chat_contactbg_color", chat_contactbg_color );
 
-	QFont defaultFont = qApp->font();
-	i_currentSettings->buddylistFontSettings->buddylist_OnlineFont=prefs.getFont("buddylist_OnlineFont", defaultFont);
+  QFont defaultFont = qApp->font();
+  i_currentSettings->buddylistFontSettings->buddylist_OnlineFont=prefs.getFont("buddylist_OnlineFont", defaultFont);
+  i_currentSettings->buddylistFontSettings->buddylist_OfflineFont=prefs.getFont("buddylist_OfflineFont", defaultFont);
+  i_currentSettings->buddylistFontSettings->buddylist_SignOnFont=prefs.getFont("buddylist_SignOnFont", defaultFont);
+  
+  //for chat_*Font, we need the default to be 12 points.
+  defaultFont.setPointSize(12);
+	
+  // chatwindow updates!
+  QFont chat_yourFont = config.readFontEntry( "chat_yourFont", &defaultFont );
+  QFont chat_contactFont = config.readFontEntry( "chat_contactFont", &defaultFont );
 
-	i_currentSettings->buddylistFontSettings->buddylist_OfflineFont=prefs.getFont("buddylist_OfflineFont", defaultFont);
+  chat_yourFont=prefs.getFont("chat_yourFont", chat_yourFont);
+  chat_contactFont=prefs.getFont("chat_buddyFont", chat_contactFont);
+  
+  config.writeEntry( "chat_yourFont", chat_yourFont );
+  config.writeEntry( "chat_contactFont", chat_contactFont );
 
-	i_currentSettings->buddylistFontSettings->buddylist_SignOnFont=prefs.getFont("buddylist_SignOnFont", defaultFont);
+  bool chat_sound;                // Done
+  bool chat_sound_beepInitial;    // Done
+  bool chat_sound_beepReceive;    // Done
+  bool chat_sound_beepSend;       // Done
+  bool chat_sound_playFile;       // Done
+  QString chat_sound_fileSend;    // Done
+  QString chat_sound_fileReceive; // Done
+  QString chat_sound_fileInitial; // Done
 
-	//for chat_*Font, we need the default to be 12 points.
-	defaultFont.setPointSize(12);
-	i_currentSettings->chatFontSettings->chat_yourFont=prefs.getFont("chat_yourFont", defaultFont);
-	i_currentSettings->chatFontSettings->chat_buddyFont=prefs.getFont("chat_buddyFont", defaultFont);
+  chat_sound= config.readBoolEntry("chat_sound_enable", true);
+  chat_sound_beepInitial= config.readBoolEntry("chat_sound_beepInitial", true);
+  chat_sound_beepReceive= config.readBoolEntry("chat_sound_beepReceive", true);
+  chat_sound_beepSend= config.readBoolEntry("chat_sound_beepSend", true);
+  chat_sound_playFile = config.readBoolEntry("chat_sound_playFile", false);
+  chat_sound_fileSend= config.readEntry("chat_sound_fileSend", DATADIR "/sounds/Send.au");
+  chat_sound_fileReceive= config.readEntry("chat_sound_fileReceive", DATADIR "/sounds/Receive.au");
+  chat_sound_fileInitial= config.readEntry("chat_sound_fileInitial", DATADIR "/sounds/Receive.au");
 
+  chat_sound= prefs.getBool("chat_sound_enable", chat_sound);
+  chat_sound_beepInitial= prefs.getBool("chat_sound_beepInitial", chat_sound_beepInitial);
+  chat_sound_beepReceive= prefs.getBool("chat_sound_beepReceive",chat_sound_beepReceive );
+  chat_sound_beepSend= prefs.getBool("chat_sound_beepSend", chat_sound_beepSend);
+  chat_sound_playFile = prefs.getBool("chat_sound_playFile", chat_sound_playFile);
+  chat_sound_fileSend= prefs.getString("chat_sound_fileSend", chat_sound_fileSend);
+  chat_sound_fileReceive= prefs.getString("chat_sound_fileReceive", chat_sound_fileReceive);
+  chat_sound_fileInitial= prefs.getString("chat_sound_fileInitial", chat_sound_fileInitial);
+
+  config.writeEntry("chat_sound", chat_sound);
+  config.writeEntry("chat_sound_beepInitial", chat_sound_beepInitial);
+  config.writeEntry("chat_sound_beepReceive", chat_sound_beepReceive);
+  config.writeEntry("chat_sound_beepSend", chat_sound_beepSend);
+  config.writeEntry("chat_sound_playFile", chat_sound_playFile);
+  config.writeEntry("chat_sound_fileSend", chat_sound_fileSend);
+  config.writeEntry("chat_sound_fileReceive", chat_sound_fileReceive);
+  config.writeEntry("chat_sound_fileInitial", chat_sound_fileInitial);
 
-	i_currentSettings->chatSoundSettings->chat_sound= prefs.getBool("chat_sound_enable", true);
-	i_currentSettings->chatSoundSettings->chat_sound_beepInitial= prefs.getBool("chat_sound_beepInitial", true);
-	i_currentSettings->chatSoundSettings->chat_sound_beepReceive= prefs.getBool("chat_sound_beepReceive", true);
-	i_currentSettings->chatSoundSettings->chat_sound_beepSend= prefs.getBool("chat_sound_beepSend", true);
-	i_currentSettings->chatSoundSettings->chat_sound_playFile = prefs.getBool("chat_sound_playFile", false);
-	i_currentSettings->chatSoundSettings->chat_sound_fileSend= prefs.getString("chat_sound_fileSend", DATADIR "/sounds/Send.au");
-	i_currentSettings->chatSoundSettings->chat_sound_fileReceive= prefs.getString("chat_sound_fileReceive", DATADIR "/sounds/Receive.au");
-	i_currentSettings->chatSoundSettings->chat_sound_fileInitial= prefs.getString("chat_sound_fileInitial", DATADIR "/sounds/Receive.au");
 	i_currentSettings->IgnoreThisUpdate= prefs.getString("IgnoreThisUpdate", i_currentSettings->ReleaseDate);
 
 	prefs.setGroup("away list");
